.. module:: enaml.widgets.status_item

=========================
enaml.widgets.status_item
=========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    StatusItem


.. autoclass:: StatusItem
